aboutsummaryrefslogtreecommitdiff
path: root/include/sway
diff options
context:
space:
mode:
Diffstat (limited to 'include/sway')
-rw-r--r--include/sway/tree/view.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/include/sway/tree/view.h b/include/sway/tree/view.h
index d0093db5..fc4c8df9 100644
--- a/include/sway/tree/view.h
+++ b/include/sway/tree/view.h
@@ -72,10 +72,11 @@ struct sway_view {
list_t *marks; // char *
list_t *instructions; // struct sway_transaction_instruction *
- // If saved_texture is set, the main surface of the view will render this
- // texture instead of its own. This is used while waiting for transactions
- // to complete.
- struct wlr_texture *saved_texture;
+ // If saved_buffer is set, the main surface of the view will render this
+ // buffer/texture instead of its own. This is used while waiting for
+ // transactions to complete.
+ struct wlr_buffer *saved_buffer;
+ int saved_surface_width, saved_surface_height;
struct wlr_texture *marks_focused;
struct wlr_texture *marks_focused_inactive;